pub enum MessagePart {
Text {
text: String,
},
ToolOutput {
tool_name: String,
body: String,
compacted_at: Option<i64>,
},
Recall {
text: String,
},
CodeContext {
text: String,
},
Summary {
text: String,
},
CrossSession {
text: String,
},
ToolUse {
id: String,
name: String,
input: Value,
},
ToolResult {
tool_use_id: String,
content: String,
is_error: bool,
},
Image(Box<ImageData>),
ThinkingBlock {
thinking: String,
signature: String,
},
RedactedThinkingBlock {
data: String,
},
Compaction {
summary: String,
},
}Variants
Text
ToolOutput
Recall
CodeContext
Summary
CrossSession
ToolUse
ToolResult
Image(Box<ImageData>)
ThinkingBlock
Claude thinking block — must be preserved verbatim in multi-turn requests.
RedactedThinkingBlock
Claude redacted thinking block — preserved as-is in multi-turn requests.
Compaction
Claude server-side compaction block — must be preserved verbatim in multi-turn requests so the API can correctly prune prior history on the next turn.
Implementations
Sourceimpl MessagePart
impl MessagePart
Sourcepub fn as_plain_text(&self) -> Option<&str>
pub fn as_plain_text(&self) -> Option<&str>
Return the plain text content if this part is a text-like variant (Text, Recall,
CodeContext, Summary, CrossSession), None otherwise.